@@ -1,14 +1,15 @@
 package Process::Launcher;
 
+use 5.00503;
 use strict;
-use Exporter ();
-use Process  ();
+use Exporter              ();
+use Params::Util          ();
+use Process               ();
 use Process::Serializable ();
-use Params::Util qw{_CLASS _INSTANCE};
 
 use vars qw{$VERSION @ISA @EXPORT};
 BEGIN {
-	$VERSION = '0.22';
+	$VERSION = '0.23';
 	@ISA     = qw{Exporter};
 	@EXPORT  = qw{run run3 serialized};
 
@@ -28,8 +29,10 @@ sub run() {
 	my $class  = load(shift @ARGV);
 
 	# Create the object
-	my $object = $class->new( @ARGV )
-		or fail("$class->new returned false");
+	my $object = $class->new( @ARGV );
+	unless ( $object ) {
+		fail("$class->new returned false");
+	}
 
 	# Run it
 	execute($object);
@@ -117,7 +120,7 @@ sub execute($) {
 
 sub load($) {
 	my $class = shift;
-	unless ( _CLASS($class) ) {
+	unless ( Params::Util::_CLASS($class) ) {
 		fail("Did not provide a valid class as first argument");
 	}
 	eval "require $class";
@@ -253,11 +256,15 @@ For other issues, contact the author.
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>, L<http://ali.as/>
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+
+=head1 SEE ALSO
+
+L<http://ali.as/>
 
 =head1 COPYRIGHT
 
-Copyright 2006 Adam Kennedy.
+Copyright 2006 - 2009 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
